import {expect} from 'chai';
import * as sinon from 'sinon';
import {capitalize, clearDocumentHTML} from '../helpers';
import {pwinbox} from '../constants';
import {PWInboxWidget as InboxWidget} from '../../src';

export default () => {
    const sandbox = sinon.createSandbox();

    it('Widget is placed on page by default method', () => {
        clearDocumentHTML();

        const params = {
            enable: true,
            pwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger'
            }
        };
        const inbox = new InboxWidget(params as any);

        const defaultPlaceWidgetSpy = sandbox.spy(inbox, <any>'defaultPlaceWidget');

        inbox.toggle(true);

        expect(defaultPlaceWidgetSpy.called).is.true;
    });

    it('Widget placed to custom element by customPlaceWidget method', () => {
        clearDocumentHTML();

        const params = {
            enable: true,
            pwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger',
                appendTo: '#parentElement'
            }
        };
        const inbox = new InboxWidget(params as any);

        const customPlaceWidgetSpy = sandbox.spy(inbox, <any>'customPlaceWidget');

        inbox.toggle(true);

        expect(customPlaceWidgetSpy.called).is.true;
    });

    ['left', 'bottom', 'right', 'top'].forEach((position: string) => {
        it(`Widget Widget should have pw-${position} classname`, () => {
            clearDocumentHTML();
            const params = {
                enable: true,
                pwinbox,
                push: async () => {},
                inboxWidgetConfig: {
                    triggerId: 'unfixedTrigger',
                    position: position
                }
            };

            const inbox = new InboxWidget(params as any);

            const spy = sandbox.spy(inbox, <any>`alignWidget${capitalize(position)}`);
            inbox.trigger.click();

            expect(spy.called).is.true;
            expect(inbox.widget.className).is.contains(`pw-${position}`);
        });
    });

}