import {fullPwinbox, messagesMock} from '../constants';
import {PWInboxWidget as InboxWidget} from '../../src';
import {expect} from 'chai';

export default () => {

    it('Render widget with 3 messages elements', () => {
        const params = {
            enable: true,
            pwinbox: fullPwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger'
            }
        };
        const inbox = new InboxWidget(params as any);
        inbox['updateInboxMessages'](messagesMock);
        expect(inbox.widget.querySelectorAll('.pw-inbox_item-inner').length).is.equal(messagesMock.length);
    });

    it('Render unread message with classname pw-new', () => {
        const params = {
            enable: true,
            pwinbox: fullPwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger'
            }
        };
        const inbox = new InboxWidget(params as any);
        inbox['updateInboxMessages'](messagesMock);
        const unreadMessage = messagesMock.find((message: IInboxMessagePublic):boolean => !message.isRead);
        const unreadMessageElement =
            inbox.widget.querySelector(`[data-pw-inbox-message-id=${unreadMessage ? unreadMessage.code : ''}]`)
            || document.createElement('li');
        expect(unreadMessageElement.className).to.include('pw-new');
    });

    it('Render unperfomed message with classname pw-unread', () => {
        const params = {
            enable: true,
            pwinbox: fullPwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger'
            }
        };
        const inbox = new InboxWidget(params as any);
        inbox['updateInboxMessages'](messagesMock);
        const unreadMessage = messagesMock.find((message: IInboxMessagePublic):boolean => !message.isActionPerformed);
        const unreadMessageElement =
            inbox.widget.querySelector(`[data-pw-inbox-message-id=${unreadMessage ? unreadMessage.code : ''}]`)
            || document.createElement('li');
        expect(unreadMessageElement.className).to.include('pw-unread');
    });

    it('messagesElements contains links to messages elements', () => {
        const params = {
            enable: true,
            pwinbox: fullPwinbox,
            push: async () => {},
            inboxWidgetConfig: {
                triggerId: 'unfixedTrigger'
            }
        };
        const inbox = new InboxWidget(params as any);
        inbox['updateInboxMessages'](messagesMock);
        expect(Object.keys(inbox.messagesElements).length).is.equal(messagesMock.length);
    });
};